ComputePassEncoder class

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

bindPipeline(GpuComputePipeline pipeline) → void
dispatch(int x, [int y = 1, int z = 1]) → void
end() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setBindGroup(int index, WGPUBindGroup group) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited