GpuBuffer class

Inheritance

Properties

handle Pointer<Void>
finalinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size int
final
usage int
final

Methods

dispose() → void
mapRead() Future<Uint8List>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
update(Uint8List data) → void
updateRaw(Pointer<Void> data, int dataSize) → void
updateRawOffset(Uint8List data, int bufferOffset) → void
uploadMatrix(Matrix4 matrix, {int offset = 0}) → void

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

create({required int size, required int usage}) GpuBuffer