GpuComputePipeline class

Inheritance

Properties

handle Pointer<Void>
finalinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createBindGroup(int index, List<Object> resources) WGPUBindGroup
dispose() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

create(GpuShader shader, {String entryPoint = "main"}) GpuComputePipeline