GpuRenderPipeline class

Inheritance

Properties

handle Pointer<Void>
finalinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createBindGroup(int index, List<Object> resources) WGPUBindGroup
dispose() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

create({required GpuShader vertexShader, required GpuShader fragmentShader, required List<VertexBufferLayout> bufferLayouts, BlendMode blendMode = BlendMode.opaque, bool enableDepth = false, WGPUTextureFormat depthFormat = WGPUTextureFormat.WGPUTextureFormat_Depth24Plus, String vertexEntryPoint = "main", String fragmentEntryPoint = "main", int sampleCount = 1, WGPUTextureFormat? targetFormat, WGPUPrimitiveTopology topology = WGPUPrimitiveTopology.WGPUPrimitiveTopology_TriangleStrip, WGPUCullMode cullMode = WGPUCullMode.WGPUCullMode_None, WGPUFrontFace frontFace = WGPUFrontFace.WGPUFrontFace_CCW}) GpuRenderPipeline