GpuSampler class

Inheritance

Properties

handle Pointer<Void>
finalinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispose() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

create({WGPUAddressMode addressMode = WGPUAddressMode.WGPUAddressMode_ClampToEdge, WGPUFilterMode filter = WGPUFilterMode.WGPUFilterMode_Linear, WGPUCompareFunction compare = WGPUCompareFunction.WGPUCompareFunction_Undefined}) GpuSampler