VertexAttribute class

Constructors

VertexAttribute({required WGPUVertexFormat format, required int offset, required int shaderLocation})
const

Properties

format WGPUVertexFormat
final
hashCode int
The hash code for this object.
no setterinherited
offset int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shaderLocation int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited