VertexBufferLayout class

Constructors

VertexBufferLayout({required int arrayStride, required WGPUVertexStepMode stepMode, required List<VertexAttribute> attributes})

Properties

arrayStride int
final
attributes List<VertexAttribute>
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stepMode WGPUVertexStepMode
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromFormats(List<WGPUVertexFormat> formats, {WGPUVertexStepMode stepMode = WGPUVertexStepMode.WGPUVertexStepMode_Vertex, int startShaderLocation = 0}) VertexBufferLayout