MeshData class

Constructors

MeshData(Float32List vertices, Uint32List indices, List<MeshGroup> groups, String? mtlLibName)

Properties

groups List<MeshGroup>
final
hashCode int
The hash code for this object.
no setterinherited
indices Uint32List
final
mtlLibName String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
vertices Float32List
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited