BlendMode enum
Values
- opaque → const BlendMode
-
No blending. Replaces destination pixels.
- alpha → const BlendMode
-
alpha blending: (Src * SrcAlpha) + (Dst * (1 - SrcAlpha))
- add → const BlendMode
-
Additive blending: Src + Dst
- max → const BlendMode
-
Retains the maximum component value: Max(Src, Dst)
- min → const BlendMode
-
Retains the minimum component value: Min(Src, Dst)
- erase → const BlendMode
-
Erases destination based on source alpha: Dst * (1 - SrcAlpha)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited