CommandEncoder class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
beginComputePass(
) → ComputePassEncoder -
beginRenderPass(
GpuTexture texture, {Color? clearColor, int sampleCount = 1, GpuTexture? msaaTexture, GpuTexture? depthTexture, WGPULoadOp loadOp = WGPULoadOp.WGPULoadOp_Load, WGPUStoreOp storeOp = WGPUStoreOp.WGPUStoreOp_Store}) → RenderPassEncoder -
copyTextureToTexture(
{required GpuTexture from, required GpuTexture to}) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
submit(
) → void -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited