GpuTexture class
- Implemented types
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- texture → WGPUTexture
-
final
- textureId → int
-
final
- view → WGPUTextureView
-
final
- width → int
-
final
Methods
-
beginAccess(
) → void -
dispose(
) → void -
download(
) → Future< Uint8List> -
endAccess(
) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
present(
) → void -
toString(
) → String -
A string representation of this object.
inherited
-
uploadRect(
Uint8List data, Rect rect) → void
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
create(
{required int width, required int height}) → Future< GpuTexture> -
createDepth(
{required int width, required int height, int samples = 1}) → GpuTexture -
createMsaa(
{required int width, required int height, int samples = 4}) → GpuTexture