RenderPassEncoder class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
bindPipeline(GpuRenderPipeline pipeline)
→ void
-
-
draw(int vertexCount)
→ void
-
-
drawIndexed(int indexCount, [int instanceCount = 1, int firstIndex = 0, int baseVertex = 0, int firstInstance = 0])
→ void
-
-
drawInstanced(int vertexCount, int instanceCount)
→ void
-
-
end()
→ void
-
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
setBindGroup(int index, WGPUBindGroup group)
→ void
-
-
setIndexBuffer(GpuBuffer buffer, WGPUIndexFormat format, [int offset = 0, int size = 0])
→ void
-
-
setVertexBuffer(int slot, GpuBuffer buffer)
→ void
-
-
toString()
→ String
-
A string representation of this object.
inherited